@@ -5,5 +5,5 @@ def test_mdoc_from_tilt_series_mdoc_file(tilt_series_mdoc_file):
     mdoc = Mdoc.from_file(tilt_series_mdoc_file)
     assert isinstance(mdoc, Mdoc)
     assert len(mdoc.titles) == 2
-    assert mdoc.global_data.pixel_spacing == 5.4
+    assert mdoc.global_data.PixelSpacing == 5.4
     assert len(mdoc.section_data) == 41
\ No newline at end of file
